View source: R/initialize_project.R
| set_results | R Documentation |
Sets the results folder in the project environment and creates a date-based subfolder.
The date-based folder is accessible via proj$results_today and empty date folders
are automatically cleaned up when new results are added.
set_results(results, proj = org::project)
results |
A character vector specifying one or more possible results folder paths. The first existing path will be used. |
proj |
The project environment. Default is |
Nothing. Modifies the proj environment to include:
The base results folder path
Path to today's results folder (format: YYYY-MM-DD)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.